package com.muyu.customer.business.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.customer.business.domain.Vehicle;
import com.muyu.customer.business.domain.req.VehicleQueryReq;
import com.muyu.customer.business.domain.req.VehicleSaveReq;
import com.muyu.customer.business.domain.req.VehicleEditReq;
import com.muyu.customer.business.service.VehicleService;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 车辆录入Controller
 *
 * @author muyu
 * @date 2024-05-27
 */
@Api(tags = "车辆录入")
@RestController
@RequestMapping("/vehicle")
public class VehicleController extends BaseController {
    @Autowired
    private VehicleService vehicleService;

    /**
     * 查询车辆录入列表
     */
    @ApiOperation("获取车辆录入列表")
    @RequiresPermissions("customerBusiness:vehicle:list")
    @GetMapping("/list")
    public Result<TableDataInfo<Vehicle>> list(VehicleQueryReq vehicleQueryReq) {
        startPage();
        List<Vehicle> list = vehicleService.list(Vehicle.queryBuild(vehicleQueryReq));
        return getDataTable(list);
    }

    /**
     * 导出车辆录入列表
     */
    @ApiOperation("导出车辆录入列表")
    @RequiresPermissions("customerBusiness:vehicle:export")
    @Log(title = "车辆录入", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Vehicle vehicle) {
        List<Vehicle> list = vehicleService.list(vehicle);
        ExcelUtil<Vehicle> util = new ExcelUtil<Vehicle>(Vehicle.class);
        util.exportExcel(response, list, "车辆录入数据");
    }

    /**
     * 获取车辆录入详细信息
     */
    @ApiOperation("获取车辆录入详细信息")
    @RequiresPermissions("customerBusiness:vehicle:query")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<Vehicle> getInfo(@PathVariable("id") Long id) {
        return Result.success(vehicleService.getById(id));
    }

    /**
     * 新增车辆录入
     */
    @RequiresPermissions("customerBusiness:vehicle:add")
    @Log(title = "车辆录入", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增车辆录入")
    public Result<String> add(@RequestBody VehicleSaveReq vehicleSaveReq) {
        return toAjax(vehicleService.save(Vehicle.saveBuild(vehicleSaveReq)));
    }

    /**
     * 修改车辆录入
     */
    @RequiresPermissions("customerBusiness:vehicle:edit")
    @Log(title = "车辆录入", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改车辆录入")
    public Result<String> edit(@PathVariable Long id, @RequestBody VehicleEditReq vehicleEditReq) {
        return toAjax(vehicleService.updateById(Vehicle.editBuild(id,vehicleEditReq)));
    }

    /**
     * 删除车辆录入
     */
    @RequiresPermissions("customerBusiness:vehicle:remove")
    @Log(title = "车辆录入", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除车辆录入")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        return toAjax(vehicleService.removeBatchByIds(ids));
    }
}
