package com.muyu.net.working.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.net.working.domain.Enterprise;
import com.muyu.net.working.domain.req.EnterpriseQueryReq;
import com.muyu.net.working.domain.req.EnterpriseSaveReq;
import com.muyu.net.working.domain.req.EnterpriseEditReq;
import com.muyu.net.working.service.EnterpriseService;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 企业信息Controller
 *
 * @author muyu
 * @date 2024-05-27
 */
@Api(tags = "企业信息")
@RestController
@RequestMapping("/car")
public class EnterpriseController extends BaseController {
    @Autowired
    private EnterpriseService enterpriseService;

    /**
     * 查询企业信息列表
     */
    @ApiOperation("获取企业信息列表")
    @RequiresPermissions("netWorking:car:list")
    @GetMapping("/list")
    public Result<TableDataInfo<Enterprise>> list(EnterpriseQueryReq enterpriseQueryReq) {
        startPage();
        List<Enterprise> list = enterpriseService.list(Enterprise.queryBuild(enterpriseQueryReq));
        return getDataTable(list);
    }

    /**
     * 导出企业信息列表
     */
    @ApiOperation("导出企业信息列表")
    @RequiresPermissions("netWorking:car:export")
    @Log(title = "企业信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Enterprise enterprise) {
        List<Enterprise> list = enterpriseService.list(enterprise);
        ExcelUtil<Enterprise> util = new ExcelUtil<Enterprise>(Enterprise.class);
        util.exportExcel(response, list, "企业信息数据");
    }

    /**
     * 获取企业信息详细信息
     */
    @ApiOperation("获取企业信息详细信息")
    @RequiresPermissions("netWorking:car:query")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "String", paramType = "path", dataTypeClass = String.class)
    public Result<Enterprise> getInfo(@PathVariable("id") String id) {
        return Result.success(enterpriseService.getById(id));
    }

    /**
     * 新增企业信息
     */
    @RequiresPermissions("netWorking:car:add")
    @Log(title = "企业信息", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增企业信息")
    public Result<String> add(@RequestBody EnterpriseSaveReq enterpriseSaveReq) {
        return toAjax(enterpriseService.save(Enterprise.saveBuild(enterpriseSaveReq)));
    }

    /**
     * 修改企业信息
     */
    @RequiresPermissions("netWorking:car:edit")
    @Log(title = "企业信息", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改企业信息")
    public Result<String> edit(@PathVariable String id, @RequestBody EnterpriseEditReq enterpriseEditReq) {
        return toAjax(enterpriseService.updateById(Enterprise.editBuild(id,enterpriseEditReq)));
    }

    /**
     * 删除企业信息
     */
    @RequiresPermissions("netWorking:car:remove")
    @Log(title = "企业信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除企业信息")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "String", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<String> ids) {
        return toAjax(enterpriseService.removeBatchByIds(ids));
    }
}
